==> haskell-ipython-kernel-0.11.0.0-93-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-ipython-kernel.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ipython-kernel
version:              0.11.0.0
visibility:           public
id:                   ipython-kernel-0.11.0.0-5UuCuxJtrZsJ437t83w7C2
key:                  ipython-kernel-0.11.0.0-5UuCuxJtrZsJ437t83w7C2
license:              MIT
maintainer:           andrew.gibiansky@gmail.com
author:               Andrew Gibiansky
homepage:             http://github.com/gibiansky/IHaskell
synopsis:             A library for creating kernels for IPython frontends
description:
    ipython-kernel is a library for communicating with frontends for the interactive IPython framework. It is used extensively in IHaskell, the interactive Haskell environment.

category:             Development
abi:                  23c87dc11e8fb73ae39bd166cca24373
exposed:              True
exposed-modules:
    IHaskell.IPython.EasyKernel IHaskell.IPython.Kernel
    IHaskell.IPython.Message.Parser IHaskell.IPython.Message.UUID
    IHaskell.IPython.Types IHaskell.IPython.ZeroMQ

import-dirs:          /usr/lib/ghc-9.4.8/site-local/ipython-kernel-0.11.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/ipython-kernel-0.11.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/ipython-kernel-0.11.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ipython-kernel
hs-libraries:         HSipython-kernel-0.11.0.0-5UuCuxJtrZsJ437t83w7C2
depends:
    aeson-2.1.2.1-H9spCVKCz3aBZuysSTfrjv base-4.17.2.1 binary-0.8.9.1
    bytestring-0.11.5.3 containers-0.6.7
    cryptonite-0.30-9aiao6Baet5LbFVZqeOgvR directory-1.3.7.1
    filepath-1.4.2.2 memory-0.18.0-1oHOZXUPjWrG0kImkORGvt
    parsec-3.1.16.1 process-1.6.18.0
    temporary-1.3-8FAts4F1AmtHqh7aYyLCzN text-2.0.2
    transformers-0.5.6.2
    unordered-containers-0.2.20-L3M6eILO3KM5ipeNJik2xY
    uuid-1.3.16-DTXFgrb7MThGeAanhZvVIB
    zeromq4-haskell-0.8.0-GbT1b2ijVFOFbNnqUyYVua

haddock-interfaces:
    /usr/share/doc/haskell-ipython-kernel/html/ipython-kernel.haddock

haddock-html:         /usr/share/doc/haskell-ipython-kernel/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-ipython-kernel-0.11.0.0-94-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-ipython-kernel.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ipython-kernel
version:              0.11.0.0
visibility:           public
id:                   ipython-kernel-0.11.0.0-AiTeUua3l3N9mA1jACeLC4
key:                  ipython-kernel-0.11.0.0-AiTeUua3l3N9mA1jACeLC4
license:              MIT
maintainer:           andrew.gibiansky@gmail.com
author:               Andrew Gibiansky
homepage:             http://github.com/gibiansky/IHaskell
synopsis:             A library for creating kernels for IPython frontends
description:
    ipython-kernel is a library for communicating with frontends for the interactive IPython framework. It is used extensively in IHaskell, the interactive Haskell environment.

category:             Development
abi:                  92a3b795e7de0281d6dac0e7e990c98b
exposed:              True
exposed-modules:
    IHaskell.IPython.EasyKernel IHaskell.IPython.Kernel
    IHaskell.IPython.Message.Parser IHaskell.IPython.Message.UUID
    IHaskell.IPython.Types IHaskell.IPython.ZeroMQ

import-dirs:          /usr/lib/ghc-9.4.8/site-local/ipython-kernel-0.11.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/ipython-kernel-0.11.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/ipython-kernel-0.11.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ipython-kernel
hs-libraries:         HSipython-kernel-0.11.0.0-AiTeUua3l3N9mA1jACeLC4
depends:
    aeson-2.1.2.1-LRjlcarryWV47QfBrWIlNe base-4.17.2.1 binary-0.8.9.1
    bytestring-0.11.5.3 containers-0.6.7
    cryptonite-0.30-3yYlvSkPYZuEKec1R0Vp9e directory-1.3.7.1
    filepath-1.4.2.2 memory-0.18.0-1oHOZXUPjWrG0kImkORGvt
    parsec-3.1.16.1 process-1.6.18.0
    temporary-1.3-KrnV93DB6hBAYgorLtz1qq text-2.0.2
    transformers-0.5.6.2
    unordered-containers-0.2.20-66FGtARgHXEQRH0VfdDtx
    uuid-1.3.16-7KXHlNOPcUrJHrkgdp2jGD
    zeromq4-haskell-0.8.0-Lj3chYCsnUpJJmDr4KRtHu

haddock-interfaces:
    /usr/share/doc/haskell-ipython-kernel/html/ipython-kernel.haddock

haddock-html:         /usr/share/doc/haskell-ipython-kernel/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
